==> plugin-android-3.1.3-sources.jar: com/zoyi/channel/plugin/android/view/layout/CHTextView.java <==
package com.zoyi.channel.plugin.android.view.layout;

import android.content.Context;
import android.content.res.TypedArray;
import android.support.annotation.Nullable;
import android.support.v7.widget.AppCompatTextView;
import android.util.AttributeSet;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.event.LanguageBus;
import com.zoyi.channel.plugin.android.event.RxBus;
import com.zoyi.channel.plugin.android.util.L;
import com.zoyi.channel.plugin.android.util.ResUtils;
import com.zoyi.rx.Subscription;
import com.zoyi.rx.android.schedulers.AndroidSchedulers;
import com.zoyi.rx.functions.Action1;
import com.zoyi.rx.schedulers.Schedulers;

public class CHTextView extends AppCompatTextView {

  private Context context;

  private String textKey;
  private Subscription subscription;

  public CHTextView(Context context) {
    super(context);
    init(context, null);
  }

  public CHTextView(Context context, @Nullable AttributeSet attrs) {
    super(context, attrs);
    init(context, attrs);

  }

  public CHTextView(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
    super(context, attrs, defStyleAttr);
    init(context, attrs);
  }

  private void init(Context context, AttributeSet attrs) {
    this.context = context;
    subscribe();
    setTypeArray(attrs);
  }

  private void setTypeArray(AttributeSet attrs) {
    if (attrs != null) {
      TypedArray typedArray = getContext().obtainStyledAttributes(attrs, R.styleable.ChannelCustomView);
      textKey = typedArray.getString(R.styleable.ChannelCustomView_ch_text_key);
      setTextByKey(textKey);
    }
  }

  private void subscribe() {
    subscription = RxBus.observable()
        .onBackpressureBuffer()
        .subscribeOn(Schedulers.newThread())
        .observeOn(AndroidSchedulers.mainThread())
        .subscribe(new Action1<Object>() {
          @Override
          public void call(Object o) {
            onReceiveEvent(o);
          }
        });
  }

  private void onReceiveEvent(Object object) {
    if (object instanceof LanguageBus && textKey != null) {
      setTextByKey(textKey);
    }
  }

  public void setTextByKey(String key) {
    if (key != null) {
      this.textKey = key;
      super.setText(ResUtils.getString(context, key));
    }
  }

  @Override
  protected void onDetachedFromWindow() {
    if (!subscription.isUnsubscribed()) {
      subscription.unsubscribe();
    }
    super.onDetachedFromWindow();
  }
}

==> plugin-android-3.1.5-sources.jar: com/zoyi/channel/plugin/android/view/layout/CHTextView.java <==
package com.zoyi.channel.plugin.android.view.layout;

import android.content.Context;
import android.content.res.TypedArray;
import android.support.annotation.Nullable;
import android.support.v7.widget.AppCompatTextView;
import android.util.AttributeSet;

import com.zoyi.channel.plugin.android.R;
import com.zoyi.channel.plugin.android.event.LanguageBus;
import com.zoyi.channel.plugin.android.event.RxBus;
import com.zoyi.channel.plugin.android.util.L;
import com.zoyi.channel.plugin.android.util.ResUtils;
import com.zoyi.channel.plugin.android.util.Utils;
import com.zoyi.rx.Subscription;
import com.zoyi.rx.android.schedulers.AndroidSchedulers;
import com.zoyi.rx.functions.Action1;
import com.zoyi.rx.schedulers.Schedulers;

public class CHTextView extends AppCompatTextView {

  private Context context;

  private String textKey;
  private boolean isHTMLText;
  private Subscription subscription;

  public CHTextView(Context context) {
    super(context);
    init(context, null);
  }

  public CHTextView(Context context, @Nullable AttributeSet attrs) {
    super(context, attrs);
    init(context, attrs);

  }

  public CHTextView(Context context, @Nullable AttributeSet attrs, int defStyleAttr) {
    super(context, attrs, defStyleAttr);
    init(context, attrs);
  }

  private void init(Context context, AttributeSet attrs) {
    this.context = context;
    subscribe();
    setTypeArray(attrs);
  }

  private void setTypeArray(AttributeSet attrs) {
    if (attrs != null) {
      TypedArray typedArray = getContext().obtainStyledAttributes(attrs, R.styleable.ChannelCustomView);
      textKey = typedArray.getString(R.styleable.ChannelCustomView_ch_text_key);
      isHTMLText = typedArray.getBoolean(R.styleable.ChannelCustomView_ch_html_text, false);
      setTextByKey(textKey);
    }
  }

  private void subscribe() {
    subscription = RxBus.observable()
        .onBackpressureBuffer()
        .subscribeOn(Schedulers.newThread())
        .observeOn(AndroidSchedulers.mainThread())
        .subscribe(new Action1<Object>() {
          @Override
          public void call(Object o) {
            onReceiveEvent(o);
          }
        });
  }

  private void onReceiveEvent(Object object) {
    if (object instanceof LanguageBus && textKey != null) {
      setTextByKey(textKey);
    }
  }

  public void setTextByKey(String key) {
    if (key != null) {
      this.textKey = key;

      if (isHTMLText) {
        super.setText(Utils.getHtmlFormattedText(ResUtils.getString(context, key)));
      } else {
        super.setText(ResUtils.getString(context, key));
      }
    }
  }

  @Override
  protected void onDetachedFromWindow() {
    if (!subscription.isUnsubscribed()) {
      subscription.unsubscribe();
    }
    super.onDetachedFromWindow();
  }
}
